function noop() { }
function assign(tar, src) {
    // @ts-ignore
    for (const k in src)
        tar[k] = src[k];
    return tar;
}
function run(fn) {
    return fn();
}
function blank_object() {
    return Object.create(null);
}
function run_all(fns) {
    fns.forEach(run);
}
function is_function(thing) {
    return typeof thing === 'function';
}
function safe_not_equal(a, b) {
    return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
}
function create_slot(definition, ctx, $$scope, fn) {
    if (definition) {
        const slot_ctx = get_slot_context(definition, ctx, $$scope, fn);
        return definition[0](slot_ctx);
    }
}
function get_slot_context(definition, ctx, $$scope, fn) {
    return definition[1] && fn
        ? assign($$scope.ctx.slice(), definition[1](fn(ctx)))
        : $$scope.ctx;
}
function get_slot_changes(definition, $$scope, dirty, fn) {
    if (definition[2] && fn) {
        const lets = definition[2](fn(dirty));
        if (typeof $$scope.dirty === 'object') {
            const merged = [];
            const len = Math.max($$scope.dirty.length, lets.length);
            for (let i = 0; i < len; i += 1) {
                merged[i] = $$scope.dirty[i] | lets[i];
            }
            return merged;
        }
        return $$scope.dirty | lets;
    }
    return $$scope.dirty;
}

function append(target, node) {
    target.appendChild(node);
}
function insert(target, node, anchor) {
    target.insertBefore(node, anchor || null);
}
function detach(node) {
    node.parentNode.removeChild(node);
}
function element(name) {
    return document.createElement(name);
}
function text(data) {
    return document.createTextNode(data);
}
function space() {
    return text(' ');
}
function empty() {
    return text('');
}
function attr(node, attribute, value) {
    if (value == null)
        node.removeAttribute(attribute);
    else if (node.getAttribute(attribute) !== value)
        node.setAttribute(attribute, value);
}
function children(element) {
    return Array.from(element.childNodes);
}
function set_style(node, key, value, important) {
    node.style.setProperty(key, value, important ? 'important' : '');
}

let current_component;
function set_current_component(component) {
    current_component = component;
}
function get_current_component() {
    if (!current_component)
        throw new Error(`Function called outside component initialization`);
    return current_component;
}
function onMount(fn) {
    get_current_component().$$.on_mount.push(fn);
}

const dirty_components = [];
const binding_callbacks = [];
const render_callbacks = [];
const flush_callbacks = [];
const resolved_promise = Promise.resolve();
let update_scheduled = false;
function schedule_update() {
    if (!update_scheduled) {
        update_scheduled = true;
        resolved_promise.then(flush);
    }
}
function add_render_callback(fn) {
    render_callbacks.push(fn);
}
function flush() {
    const seen_callbacks = new Set();
    do {
        // first, call beforeUpdate functions
        // and update components
        while (dirty_components.length) {
            const component = dirty_components.shift();
            set_current_component(component);
            update(component.$$);
        }
        while (binding_callbacks.length)
            binding_callbacks.pop()();
        // then, once components are updated, call
        // afterUpdate functions. This may cause
        // subsequent updates...
        for (let i = 0; i < render_callbacks.length; i += 1) {
            const callback = render_callbacks[i];
            if (!seen_callbacks.has(callback)) {
                callback();
                // ...so guard against infinite loops
                seen_callbacks.add(callback);
            }
        }
        render_callbacks.length = 0;
    } while (dirty_components.length);
    while (flush_callbacks.length) {
        flush_callbacks.pop()();
    }
    update_scheduled = false;
}
function update($$) {
    if ($$.fragment !== null) {
        $$.update();
        run_all($$.before_update);
        const dirty = $$.dirty;
        $$.dirty = [-1];
        $$.fragment && $$.fragment.p($$.ctx, dirty);
        $$.after_update.forEach(add_render_callback);
    }
}
const outroing = new Set();
let outros;
function group_outros() {
    outros = {
        r: 0,
        c: [],
        p: outros // parent group
    };
}
function check_outros() {
    if (!outros.r) {
        run_all(outros.c);
    }
    outros = outros.p;
}
function transition_in(block, local) {
    if (block && block.i) {
        outroing.delete(block);
        block.i(local);
    }
}
function transition_out(block, local, detach, callback) {
    if (block && block.o) {
        if (outroing.has(block))
            return;
        outroing.add(block);
        outros.c.push(() => {
            outroing.delete(block);
            if (callback) {
                if (detach)
                    block.d(1);
                callback();
            }
        });
        block.o(local);
    }
}
function mount_component(component, target, anchor) {
    const { fragment, on_mount, on_destroy, after_update } = component.$$;
    fragment && fragment.m(target, anchor);
    // onMount happens before the initial afterUpdate
    add_render_callback(() => {
        const new_on_destroy = on_mount.map(run).filter(is_function);
        if (on_destroy) {
            on_destroy.push(...new_on_destroy);
        }
        else {
            // Edge case - component was destroyed immediately,
            // most likely as a result of a binding initialising
            run_all(new_on_destroy);
        }
        component.$$.on_mount = [];
    });
    after_update.forEach(add_render_callback);
}
function destroy_component(component, detaching) {
    const $$ = component.$$;
    if ($$.fragment !== null) {
        run_all($$.on_destroy);
        $$.fragment && $$.fragment.d(detaching);
        // TODO null out other refs, including component.$$ (but need to
        // preserve final state?)
        $$.on_destroy = $$.fragment = null;
        $$.ctx = [];
    }
}
function make_dirty(component, i) {
    if (component.$$.dirty[0] === -1) {
        dirty_components.push(component);
        schedule_update();
        component.$$.dirty.fill(0);
    }
    component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
}
function init(component, options, instance, create_fragment, not_equal, props, dirty = [-1]) {
    const parent_component = current_component;
    set_current_component(component);
    const prop_values = options.props || {};
    const $$ = component.$$ = {
        fragment: null,
        ctx: null,
        // state
        props,
        update: noop,
        not_equal,
        bound: blank_object(),
        // lifecycle
        on_mount: [],
        on_destroy: [],
        before_update: [],
        after_update: [],
        context: new Map(parent_component ? parent_component.$$.context : []),
        // everything else
        callbacks: blank_object(),
        dirty
    };
    let ready = false;
    $$.ctx = instance
        ? instance(component, prop_values, (i, ret, ...rest) => {
            const value = rest.length ? rest[0] : ret;
            if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                if ($$.bound[i])
                    $$.bound[i](value);
                if (ready)
                    make_dirty(component, i);
            }
            return ret;
        })
        : [];
    $$.update();
    ready = true;
    run_all($$.before_update);
    // `false` as a special case of no DOM component
    $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
    if (options.target) {
        if (options.hydrate) {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.l(children(options.target));
        }
        else {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.c();
        }
        if (options.intro)
            transition_in(component.$$.fragment);
        mount_component(component, options.target, options.anchor);
        flush();
    }
    set_current_component(parent_component);
}
class SvelteComponent {
    $destroy() {
        destroy_component(this, 1);
        this.$destroy = noop;
    }
    $on(type, callback) {
        const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
        callbacks.push(callback);
        return () => {
            const index = callbacks.indexOf(callback);
            if (index !== -1)
                callbacks.splice(index, 1);
        };
    }
    $set() {
        // overridden by instance, if it has props
    }
}

/* src/index.svelte generated by Svelte v3.17.3 */

function add_css() {
	var style = element("style");
	style.id = "svelte-1slpc32-style";
	style.textContent = ".placeholder.svelte-1slpc32{position:relative;background-color:#F9F9F9;overflow:hidden}.shimmer.svelte-1slpc32{width:100%;height:100%;-webkit-animation:svelte-1slpc32-loading 1s linear infinite;animation:svelte-1slpc32-loading 1s linear infinite}.shimmer.svelte-1slpc32:before{content:\"\";position:absolute;top:0;left:0;width:50%;height:100%;background:-webkit-gradient(linear, left top, right top, color-stop(20%, rgba(255, 255, 255, 0)), to(#E5E5E5));background:-o-linear-gradient(left, rgba(255, 255, 255, 0) 20%, #E5E5E5 100%);background:linear-gradient(90deg, rgba(255, 255, 255, 0) 20%, #E5E5E5 100%)}.shimmer.svelte-1slpc32:after{content:\"\";position:absolute;top:0;right:0;width:50%;height:100%;background:-webkit-gradient(linear, left top, right top, from(#E5E5E5), color-stop(20%, rgba(255, 255, 255, 0)));background:-o-linear-gradient(left, #E5E5E5 0%, rgba(255, 255, 255, 0) 20%);background:linear-gradient(90deg, #E5E5E5 0%, rgba(255, 255, 255, 0) 20%)}img.svelte-1slpc32{-webkit-animation:svelte-1slpc32-fadein 1s forwards;animation:svelte-1slpc32-fadein 1s forwards}@-webkit-keyframes svelte-1slpc32-fadein{from{opacity:0}to{opacity:1}}@keyframes svelte-1slpc32-fadein{from{opacity:0}to{opacity:1}}@-webkit-keyframes svelte-1slpc32-loading{from{-webkit-transform:translateX(-100%);transform:translateX(-100%)}to{-webkit-transform:translateX(100%);transform:translateX(100%)}}@keyframes svelte-1slpc32-loading{from{-webkit-transform:translateX(-100%);transform:translateX(-100%)}to{-webkit-transform:translateX(100%);transform:translateX(100%)}}";
	append(document.head, style);
}

// (111:0) {#if !loaded}
function create_if_block(ctx) {
	let div1;
	let div0;
	let current;
	const default_slot_template = /*$$slots*/ ctx[10].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[9], null);

	return {
		c() {
			if (!default_slot) {
				div1 = element("div");
				div0 = element("div");
			}

			if (default_slot) default_slot.c();

			if (!default_slot) {
				attr(div0, "class", "shimmer svelte-1slpc32");
				attr(div1, "class", "placeholder svelte-1slpc32");
				set_style(div1, "width", /*placeholderWidth*/ ctx[1]);
				set_style(div1, "height", /*placeholderHeight*/ ctx[2]);
			}
		},
		m(target, anchor) {
			if (!default_slot) {
				insert(target, div1, anchor);
				append(div1, div0);
			}

			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (!default_slot) {
				if (!current || dirty & /*placeholderWidth*/ 2) {
					set_style(div1, "width", /*placeholderWidth*/ ctx[1]);
				}

				if (!current || dirty & /*placeholderHeight*/ 4) {
					set_style(div1, "height", /*placeholderHeight*/ ctx[2]);
				}
			}

			if (default_slot && default_slot.p && dirty & /*$$scope*/ 512) {
				default_slot.p(get_slot_context(default_slot_template, ctx, /*$$scope*/ ctx[9], null), get_slot_changes(default_slot_template, /*$$scope*/ ctx[9], dirty, null));
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (!default_slot) {
				if (detaching) detach(div1);
			}

			if (default_slot) default_slot.d(detaching);
		}
	};
}

function create_fragment(ctx) {
	let img;
	let img_src_value;
	let t;
	let if_block_anchor;
	let current;
	let if_block = !/*loaded*/ ctx[4] && create_if_block(ctx);

	return {
		c() {
			img = element("img");
			t = space();
			if (if_block) if_block.c();
			if_block_anchor = empty();
			if (img.src !== (img_src_value = "")) attr(img, "src", img_src_value);
			attr(img, "alt", /*alt*/ ctx[0]);
			set_style(img, "display", "none");
			attr(img, "class", "svelte-1slpc32");
		},
		m(target, anchor) {
			insert(target, img, anchor);
			/*img_binding*/ ctx[11](img);
			insert(target, t, anchor);
			if (if_block) if_block.m(target, anchor);
			insert(target, if_block_anchor, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			if (!current || dirty & /*alt*/ 1) {
				attr(img, "alt", /*alt*/ ctx[0]);
			}

			if (!/*loaded*/ ctx[4]) {
				if (if_block) {
					if_block.p(ctx, dirty);
					transition_in(if_block, 1);
				} else {
					if_block = create_if_block(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(if_block_anchor.parentNode, if_block_anchor);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(img);
			/*img_binding*/ ctx[11](null);
			if (detaching) detach(t);
			if (if_block) if_block.d(detaching);
			if (detaching) detach(if_block_anchor);
		}
	};
}

function instance($$self, $$props, $$invalidate) {
	let { url = "" } = $$props;
	let { alt = "image" } = $$props;
	let { imageWidth = "100%" } = $$props;
	let { imageHeight = "" } = $$props;
	let { placeholderWidth = "100%" } = $$props;
	let { placeholderHeight = "400px" } = $$props;
	let { styling = "" } = $$props;
	let image;
	let loaded = false;

	onMount(() => {
		$$invalidate(3, image.src = url, image);

		$$invalidate(
			3,
			image.onload = () => {
				$$invalidate(4, loaded = true);
				$$invalidate(3, image.style.cssText = `width: ${imageWidth}; height: ${imageHeight};` + styling, image);
			},
			image
		);
	});

	let { $$slots = {}, $$scope } = $$props;

	function img_binding($$value) {
		binding_callbacks[$$value ? "unshift" : "push"](() => {
			$$invalidate(3, image = $$value);
		});
	}

	$$self.$set = $$props => {
		if ("url" in $$props) $$invalidate(5, url = $$props.url);
		if ("alt" in $$props) $$invalidate(0, alt = $$props.alt);
		if ("imageWidth" in $$props) $$invalidate(6, imageWidth = $$props.imageWidth);
		if ("imageHeight" in $$props) $$invalidate(7, imageHeight = $$props.imageHeight);
		if ("placeholderWidth" in $$props) $$invalidate(1, placeholderWidth = $$props.placeholderWidth);
		if ("placeholderHeight" in $$props) $$invalidate(2, placeholderHeight = $$props.placeholderHeight);
		if ("styling" in $$props) $$invalidate(8, styling = $$props.styling);
		if ("$$scope" in $$props) $$invalidate(9, $$scope = $$props.$$scope);
	};

	return [
		alt,
		placeholderWidth,
		placeholderHeight,
		image,
		loaded,
		url,
		imageWidth,
		imageHeight,
		styling,
		$$scope,
		$$slots,
		img_binding
	];
}

class Src extends SvelteComponent {
	constructor(options) {
		super();
		if (!document.getElementById("svelte-1slpc32-style")) add_css();

		init(this, options, instance, create_fragment, safe_not_equal, {
			url: 5,
			alt: 0,
			imageWidth: 6,
			imageHeight: 7,
			placeholderWidth: 1,
			placeholderHeight: 2,
			styling: 8
		});
	}
}

export default Src;
